##  AI Agent Discovery Inbox
Manage discovered AI agents and MCP servers in the AI agent discovery inbox. Review discovered items and link them to relevant fact sheets. For AI agents, you’ll also receive suggestions for connecting agents to business capabilities in your workspace. If any agents or MCP servers aren’t relevant, you can reject them.
For detailed information, see [AI Agent Discovery Inbox](https://help.sap.com/docs/leanix/ea/ai-agent-discovery-inbox?locale=en-US&state=PRODUCTION&version=CLOUD "AI agents and MCP servers discovered across your enterprise landscape appear in the AI agent discovery inbox. Learn how to review, link, and reject fact sheets related to discovered items.").
![AI Agent Discovery Inbox showing a list of discovered agents and MCP servers with details.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio20a37ad3308e49298ef02aab596859bd_LowRes.png)
AI Agent Discovery Inbox with Discovered Agents and MCP Servers
